%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  function [ g ] = gradient( x, t, y )
%
%  Purpose
%
%       Calculates the gradient of the objective function of 
%       Example 2.1 in J. Nocedal and S. J. Wright, "Numerical 
%       Optimization", Springer-Verlag, 1999
%
%  Parameters
%
%  On entry:
%
%     x        nx1 vector with approximated parameters.
%
%     t        mx1 vector with times of the observations.
%
%     y        mx1 vector with measured observations. 
%
%  On return:
%
%     g        nx1 vector with gradient of the objective function.
%
%
%  Written by L. N. Vicente.
%  February 21, 2000.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
  function [ g ] = gradient( x, t, y )
%
% Obtain dimension m.
  m = size(t,1);
%
% Calculate the residual vector at current x.
  r = y - x(1) - x(2)*exp(-(x(3)-t).^2/x(4)) - x(5)*cos(x(6).*t);
%
% Calculate the Jacobian of the residual vector.
  J = [ -ones(m,1) ...
        -exp(-(x(3)-t).^2/x(4)) ...
        2*x(2)/x(4)*exp(-(x(3)-t).^2/x(4)).*(x(3)-t) ... 
        x(2)/(x(4)^2)*exp(-(x(3)-t).^2/x(4)).*((x(3)-t).^2) ...
        -cos(x(6).*t) ...
        x(5)*sin(x(6).*t).*t ];
%
% Compute the gradient of the objective function.
  g = J'*r;
%
% End of function gradient.
